# Get started
At first you need [Ruby](https://www.ruby-lang.org/de/) and [Bundler](http://bundler.io/).

For specific generators install:
* [OptiPng](http://optipng.sourceforge.net/) for png image minimizing
* [JpegOptim](https://github.com/tjko/jpegoptim) for jpg image minimizing
* [NodeJs](https://nodejs.org/download/) to use bower and grunt https://www.npmjs.com/
* [Bower](http://bower.io/) to use bower `npm install -g bower`
* [Grunt](http://gruntjs.com/getting-started) to use grunt `npm install -g grunt-cli`

Create a new workspace folder

    mkdir my_workspace
    cd my_workspace

Create a ruby `Gemfile`

    touch Gemfile

Paste this into the `Gemfile`

    source 'https://rubygems.org'

    gem 'easy_html_generator'

For the latest development version use

    gem 'easy_html_generator', git: 'git@github.com:creative-workflow/easy-html-generator.git', branch: 'development-master'

Run in terminal

    bundle install
    ehg --init
    ehg --create my_project

Now you should see the following folder structure with `ls -alR`

    my_workspace
    ├── dist                    # the generated result will be stored here
    └── src                     # the generation input is stored here
        ├── demo
        ├── my_project            # this is a project and will be available via http://localhost:9292/my_project
        │   ├── assets
        │   │   ├── images          # content will be copied to `dist/my_project/images`
        │   │   ├── public            # public content gets directly copied to `dist/my_project/`
        │   │   ├── scripts           # content will be copied to `dist/my_project/scripts`
        │   │   └── styles            # content will be copied to `dist/my_project/styles`
        │   ├── lib
        │   │   ├── generators        # project specific generators
        │   │   └── helper            # project specific view helpers you can use in haml files
        │   ├── project.yml         # project specific generators config
        │   └── views
        │       ├── index.html.haml   # the haml file for index.html
        │       └── layout.haml       # the layout file index.html will use
        |
        └── shared                # shared content over all projects
            ├── assets              # shared assets over all projects
            │   ├── images
            │   ├── public
            │   ├── scripts
            │   └── styles
            │       └── mixins        # here are css helpers for bootstrap and head js
            ├── lib
            │   ├── generators        # generators shared over all projects
            │   └── helper            # view helpers you can use in haml files
            └── project.yml        # if a project doesnt have a `project.yml` this config will be used

Now run

    ehg --server

...and navigate your web browser to `http://localhost:9292`

After a short time of generating you should see a directory listening in your browser.

## Usage Terminal
    Usage: ehg [options]
        -s, --server [HOST_AND_PORT]     start the rack server, default: 0.0.0.0:9292
        -g, --generate [PROJECT]         generate one or all projects, default: all
        -i, --init                       initialize ehg workspace
        -c, --create [PROJECT]           create a new project from template, default: demo
        -h, --help                       Show this message



# Resources

> "[Configuration](https://github.com/creative-workflow/easy-html-generator/blob/master/docs/CONFIGURATION.md)"

> "[Generators](https://github.com/creative-workflow/easy-html-generator/blob/master/docs/GENERATORS.md)"

> "[Haml-Templating](https://github.com/creative-workflow/easy-html-generator/blob/master/docs/HAMLTEMPLATING.md)"

 >"[Contributing](https://github.com/creative-workflow/easy-html-generator/blob/master/docs/CONTRIBUTING.md)"
